@@ -11,7 +11,7 @@ class Trilio:
         )
         # Create genisis
         self.trilio.chain.append(Block(datetime.now().timestamp(), ["genisis block"]))
-        self.wallet = self.Wallet()
+        self.Wallet = self.Wallet()
         self.TradeStorage = self.TradeStorage()
         self.CollectionStorage = self.CollectionStorage()
         self.AssetStorage = self.AssetStorage()
@@ -51,7 +51,7 @@ class Trilio:
             Transaction(timestamp,data=data)
         )
         self.create_block(
-            addresses=self.Address,
+            addresses=self.Wallet,
             collections=self.CollectionStorage,
             trades=self.TradeStorage,
             assets=self.AssetStorage
@@ -136,7 +136,7 @@ class Trilio:
                     return address["info"]["balance"]
             return "Failed"
         
-        def validate_address(self, private_key=None, public_key=None):
+        def validate_wallet(self, private_key=None, public_key=None):
             r = self.require(private_key, public_key)
             if r == False:
                 return "Private and Public keys are required"
